@@ -28,7 +28,7 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 
 #include <libgnome/gnome-macros.h>
@@ -125,8 +125,9 @@ gnome_ditem_edit_class_init (GnomeDItemEditClass *klass)
         gobject_class = (GObjectClass*) klass;
 
         bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+#    ifdef HAVE_BIND_TEXTDOMAIN_CODESET
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-        textdomain (GETTEXT_PACKAGE);
+#    endif
 
         ditem_edit_signals[CHANGED] =
                 g_signal_new ("changed",
@@ -515,6 +516,7 @@ translations_select_row (GtkTreeSelection *selection,
 		GTK_ENTRY (dee->_priv->transl_comment_entry), comment);
 	
         g_free (lang);
+        g_free (generic_name);
         g_free (comment);
         g_free (name);
 }
@@ -966,7 +968,7 @@ gnome_ditem_edit_sync_display (GnomeDItemEdit *dee)
 	gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (dee->_priv->icon_entry), tmpstr);
 
 	g_free (dee->_priv->icon_theme_dir);
-	if (cs != NULL &&  ! g_path_is_absolute (cs)) {
+	if (cs != NULL && !g_path_is_absolute (cs) && tmpstr != NULL) {
 		/* this is a themed icon, see bug #119208 */
 		dee->_priv->icon_theme_dir = g_path_get_dirname (tmpstr);
 		/* FIXME: what about theme changes when the dialog is up */
@@ -1285,7 +1287,7 @@ gnome_ditem_edit_clear (GnomeDItemEdit *dee)
         gtk_entry_set_text(GTK_ENTRY(dee->_priv->name_entry), "");
         gtk_entry_set_text(GTK_ENTRY(dee->_priv->generic_name_entry), "");
         gtk_entry_set_text(GTK_ENTRY(dee->_priv->comment_entry),"");
-        gtk_entry_set_text(GTK_ENTRY(dee->_priv->exec_entry), "");  
+        gnome_file_entry_set_filename (GNOME_FILE_ENTRY (dee->_priv->exec_entry), "");
         gtk_entry_set_text(GTK_ENTRY(dee->_priv->tryexec_entry), "");
         gtk_entry_set_text(GTK_ENTRY(dee->_priv->doc_entry), "");
         gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (dee->_priv->icon_entry), "");
